"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var vue_template_compiler_1 = require("vue-template-compiler");
var parse_script_1 = require("./parse-script");
var parse_template_1 = require("./parse-template");
var script_handlers_1 = require("./script-handlers");
var template_handlers_1 = require("./template-handlers");
var cacher_1 = require("./utils/cacher");
var ERROR_EMPTY_DOCUMENT = 'The passed source is empty';
/**
 * parses the source and returns the doc
 * @param {string} source code whose documentation is parsed
 * @param {string} filePath path of the current file against whom to resolve the mixins
 * @returns {object} documentation object
 */
function parseFile(filePath, documentation) {
    var source = fs.readFileSync(filePath, {
        encoding: 'utf-8',
    });
    return parseSource(source, filePath, documentation);
}
exports.parseFile = parseFile;
/**
 * parses the source and returns the doc
 * @param {string} source code whose documentation is parsed
 * @param {string} filePath path of the current file against whom to resolve the mixins
 * @returns {object} documentation object
 */
function parseSource(source, filePath, documentation) {
    var singleFileComponent = /\.vue$/i.test(path.extname(filePath));
    var parts = null;
    if (source === '') {
        throw new Error(ERROR_EMPTY_DOCUMENT);
    }
    if (singleFileComponent) {
        parts = cacher_1.default(function () { return vue_template_compiler_1.parseComponent(source); }, source);
    }
    var scriptSource = parts ? (parts.script ? parts.script.content : undefined) : source;
    if (scriptSource) {
        var lang = (parts && parts.script && parts.script.attrs && parts.script.attrs.lang === 'ts') ||
            /\.tsx?$/i.test(path.extname(filePath))
            ? 'ts'
            : 'js';
        parse_script_1.default(scriptSource, documentation, script_handlers_1.default, { lang: lang, filePath: filePath });
    }
    // get slots from template
    if (parts && parts.template) {
        parse_template_1.default(parts.template, documentation, template_handlers_1.default, filePath);
    }
    if (!documentation.get('displayName')) {
        // a component should always have a display name
        documentation.set('displayName', path.basename(filePath).replace(/\.\w+$/, ''));
    }
}
exports.parseSource = parseSource;
//# sourceMappingURL=parse.js.map